@@ -3,10 +3,10 @@ check.bootstrap.options <- function(bootstrap, resample, n, sample.table){
     no.samples <- table(sample.table$Region.Label)
     insufficient.samples <- no.samples[no.samples < 20]
     for(i in seq(along = insufficient.samples)){
-      message(paste("Warning: Only ",insufficient.samples[i]," transect(s) in strata ",names(insufficient.samples)[i],". The estimates of variance are likely to be biased.", sep = ""))
+      warning(paste("Only ",insufficient.samples[i]," transect(s) in strata ",names(insufficient.samples)[i],". The estimates of variance are likely to be biased.\t", sep = ""), call. = FALSE, immediate. = TRUE)
     }
   }
   if(!bootstrap){
-    cat("Warning: Currently the only method of variance estimation in mads is via the bootstrap.", sep = "", fill=TRUE)
+    stop("Currently the only method of variance estimation in mads is via the bootstrap.")
   }  
-}
\ No newline at end of file
+}
